==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/sr.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Испитивање о коришћењу",
    "Sent on: {on}" : "Послато на: {on}",
    "An error occurred while sending your report." : "Грешка приликом слања извештаја.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Листа апликација <em>(за сваку апликацију: име, верзија и да ли је укључена)</em>",
    "Database environment <em>(type, version, database size)</em>" : "База <em>(тип, верзија, величина базе)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Информације о шифровању <em>(да ли је укључено?, који је подразумевани модул)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Број дељења <em>(по типу и типу дозвола)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP окружење <em>(верзија, лимити мемеорије, макс. време извршавања, макс. величина фајла)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Детаљи о инстанци сервера <em>(верзија, тип меморијског кеширања који се користи, стање закључавања, претпрегледа, аватара)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Статистике <em>(број: фајлова, корисника, складишта по типу, коментара, ознака)</em>",
    "Help improve Nextcloud" : "Помозите нам побољшамо Некстклауд",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Да ли желите да нам помогнете да побољшамо Некстклауд тако што бисте нам послали анонимне податке о Вашим подешавањима и окружењу? Ово слање можете искључити сваког тренутка у административним поставкама.",
    "Not now" : "Не сад",
    "Send usage" : "Пошаљи коришћење",
    "Never" : "Никад",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Можете нам помоћи да побољшамо Некстклауд тако што ћете послати неке податке о Вашим тренутним подешавањима и употреби.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Ми узимамо Вашу приватност веома озбиљно. Слање података је подразумевано искључено и, уколико одаберете да га укључите, прво ће бити анонимизовано и биће Вам дата опција шта да поделите. По примању извештаја, претходни се уклања. Отпремите празан извештај да обришете све претходно сачуване податке на серверу",
    "Send new report now" : "Пошаљите извештај сада",
    "Send usage survey monthly" : "Пошаљите извештај о коришћењу на месечном нивоу",
    "Data to send" : "Подаци за слање",
    "Last report" : "Последњи извештај",
    "Sent on: %s" : "Послато на: %s",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Листа апликација <em>(за сваку апликацију: име, верзија, да ли је укључена?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Детаљи о инстанци сервера <em>(верзија, тип меморијског кеширања који се користи, да ли су укључени закључавања/претпрегледи/аватари?)</em>",
    "You can help us to improve Nextcloud be sending us some data about your current setup and usage." : "Можете нам помоћи да побољшамо Некстклауд тако што ћете послати неке податке о Вашим тренутним подешавањима и употреби.",
    "We take your privacy seriously. The data are anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data are send and always see the last report send to us. When the server receives a new report of your instance, all entries from previous reports are removed. In case you disable one of the settings below, you can send a new report, to delete the data, that is currently stored on the server." : "Ми узимамо Вашу приватност веома озбиљно. Слање података је анонимизовано и можете га укључити/искључити увек, подразумевано је искључено. Испод можете одабрати шта да поделите. По примању извештаја, претходни се уклања. Отпремите празан извештај да обришете све претходно сачуване податке на серверу.",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Можете нам помоћи да побољшамо Некстклауд тако што ћете послати неке податке о Вашим тренутним подешавањима и употреби.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Ми узимамо Вашу приватност веома озбиљно. Слање података је анонимизовано и можете га укључити/искључити увек, подразумевано је искључено. Испод можете одабрати шта да поделите. По примању извештаја, претходни се уклања. Отпремите празан извештај да обришете све претходно сачуване податке на серверу."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/survey_client/l10n/sr.js <==
OC.L10N.register(
    "survey_client",
    {
    "Usage survey" : "Испитивање о коришћењу",
    "Last report sent on: {on}" : "Последњи извештај послат: {on}",
    "An error occurred while sending your report." : "Грешка приликом слања извештаја.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Листа апликација <em>(за сваку апликацију: име, верзија и да ли је укључена)</em>",
    "Database environment <em>(type, version, database size)</em>" : "База <em>(тип, верзија, величина базе)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Информације о шифровању <em>(да ли је укључено?, који је подразумевани модул)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Број дељења <em>(по типу и типу дозвола)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP окружење <em>(верзија, лимити мемеорије, макс. време извршавања, макс. величина фајла)</em>",
    "Server instance details <em>(version, memcache used, status of locking/previews/avatars)</em>" : "Детаљи о инстанци сервера <em>(верзија, тип меморијског кеширања који се користи, стање закључавања, претпрегледа, аватара)</em>",
    "Statistic <em>(number of: files, users, storages per type, comments and tags)</em>" : "Статистике <em>(број: фајлова, корисника, складишта по типу, коментара, ознака)</em>",
    "Help improve Nextcloud" : "Помозите нам побољшамо Некстклауд",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Да ли желите да нам помогнете да побољшамо Некстклауд тако што бисте нам послали анонимне податке о Вашим подешавањима и окружењу? Ово слање можете искључити сваког тренутка у административним поставкама.",
    "Not now" : "Не сад",
    "Send usage" : "Пошаљи коришћење",
    "Never" : "Никад",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Можете нам помоћи да побољшамо Некстклауд тако што ћете послати неке податке о Вашим тренутним подешавањима и употреби.",
    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "Ми узимамо Вашу приватност веома озбиљно. Слање података је подразумевано искључено и, уколико одаберете да га укључите, прво ће бити анонимизовано и биће Вам дата опција шта да поделите. По примању извештаја, претходни се уклања. Отпремите празан извештај да обришете све претходно сачуване податке на серверу",
    "Send new report now" : "Пошаљите извештај сада",
    "Send usage survey monthly" : "Пошаљите извештај о коришћењу на месечном нивоу",
    "Data to send" : "Подаци за слање",
    "Last report sent on: %s" : "Последњи извештај послат: %s",
    "Last report" : "Последњи извештај",
    "Sent on: {on}" : "Послато на: {on}",
    "App list <em>(for each app: name, version, is enabled?)</em>" : "Листа апликација <em>(за сваку апликацију: име, верзија, да ли је укључена?)</em>",
    "Server instance details <em>(version, memcache used, locking/previews/avatars enabled?)</em>" : "Детаљи о инстанци сервера <em>(верзија, тип меморијског кеширања који се користи, да ли су укључени закључавања/претпрегледи/аватари?)</em>",
    "You can help us to improve Nextcloud by sending us some data about your current setup and usage." : "Можете нам помоћи да побољшамо Некстклауд тако што ћете послати неке податке о Вашим тренутним подешавањима и употреби.",
    "We take your privacy seriously. The data is anonymized and you can enable/disable it at any time, by default it is always disabled. Below you can also adjust what kind of data is sent and always see the last report sent to us. When the server receives a new report of your instance, all entries from previous reports are removed. If you disable one of the settings below, you can send a new report, which will delete the data that is currently stored on the server." : "Ми узимамо Вашу приватност веома озбиљно. Слање података је анонимизовано и можете га укључити/искључити увек, подразумевано је искључено. Испод можете одабрати шта да поделите. По примању извештаја, претходни се уклања. Отпремите празан извештај да обришете све претходно сачуване податке на серверу.",
    "Sent on: %s" : "Послато на: %s"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
